@@ -1,3 +1,4 @@
+## offsets are saved for the vcov() to work 1-5-13
 ## revisised Friday, March 19, 2010 to correct a bug reported by Dr Willem Vervoort
 ## major revision MS Wednesday, December 29, 2004 at 18:04
 ## to unify the output and tidy the input 
@@ -29,10 +30,17 @@ gamlssNews <- function() file.show(system.file("doc", "NEWS.txt", package="gamls
 ##
 ##----------------------------------------------------------------------------------------
 .gamlss.bi.list<-c("BI", "Binomial", "BB", "Beta Binomial", "ZIBI", "ZIBB", "ZABI", "ZABB") # binomial denominators
+.gamlss.multin.list<-c("MULTIN", "MN3", "MN4", "MN5")
 ##----------------------------------------------------------------------------------------
-.gamlss.sm.list<-c("cs", "scs", "vc",             # smoothing cubic splines  : cs, scs, vc
-                   "ps", "pb", "cy", "tp", "pvc", # penalised splines        : ps, pb, cy tp pvc pbq
-                   "pbq",                         #
+.gamlss.sm.list<-c("cs", "scs", "vc","s",         # smoothing cubic splines  : cs, scs, vc
+                   "ps", "pb", "cy", "tp", "pvc", # penalised splines       : ps, pb, cy tp pvc pbq
+                   "pbm", "pbj", "pbo",           # monotone and jumps
+                   "pbq",                         # pb using Qfunction
+                   "mrf",                         # Markov random fields
+                   "mrfa",                        # Markov random fields
+                   "sap",                         # seperation of Anisotropic penalties
+                   "sap3",                        #
+                   "krig" ,                        # kriging
                    "lo",                          # loess                    : lo
                    "random","ra","rc","rash","re",# random effect            : random, ra, rc, re (lme) rash
                    "fp","pp",                     # fractional poly          : fp, pp
@@ -41,19 +49,20 @@ gamlssNews <- function() file.show(system.file("doc", "NEWS.txt", package="gamls
                    "boost",                       # boosting                 : boost
                    "fk",                          # free knot smoothing      : fk
                    "own", "test", "test0","test1",# for testing new          : own test test0 test1 
-                   "arma", "rw", "sr",            # time series              : arma, random walk
-                   "la", "ar",                    # time series              : penalised lags, auto regressive random effect models
+                   "arma",                        # time series              : arma
+                   "rw", "ar", "seas",            # time series              : random walk, ar, sesonality, 
+                   "srw", "sar",                  # time series              : seasonal rw, seasonal ar, 
+                   "la",                          # time series              : penalised lags, 
                    "tr",                          # decision trees           : tr
-                   "ga", "cr",                    # gam -Simon Wood          : ga, cr (cubic regression splines) 
+                   "ga", "cr",                    # gam - Simon Wood         : ga, cr (cubic regression splines) 
                    "nn",                          # neural netwoks           : nn
                    "sv",                          # suppor vector machines   : sv 
                    "ma",                          # mars                     : ma
                    "pr",                          # projection pursuit Reg   : pr
-				   "pc",                          # principal component regr : pc
-				   "pa")                          # partial regression       : pr
+				           "pc",                          # principal component regr : pc
+				           "pa")                          # partial regression       : pr
                    
 # note that predict only read 2 characters Monday, May 4, 2009 at 11:27
-.gamlss.multin.list<-c("MULTIN", "MN3", "MN4", "MN5")
 ##----------------------------------------------------------------------------------------
 ##========================================================================================
 ##  Generalised Additive Models for Location Scale and Shape 
@@ -167,6 +176,8 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
           d2ldp2 <- f$d2ldp2(fv) 
          d2ldp2 <-  ifelse(d2ldp2 < -1e-15, d2ldp2,-1e-15) # added 26-10-07  
               wt <- -(d2ldp2/(dr*dr))# 
+            # we need to stop the weights to go to Infty
+              wt <- ifelse(wt>1e+10,1e+10,wt) # Mikis 9-10-14    
             # wv <- (eta-os)+step*dldp/(dr*wt)
               wv <- (eta-os)+dldp/(dr*wt)
               if (family$type=="Mixed") wv <-ifelse(is.nan(wv),0,wv) ## TEST
@@ -223,7 +234,7 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
             if ((dv > olddv+gd.tol ) && itn >= 2 && iterw==FALSE) 
               {
            warning("The deviance has increased in an inner iteration for ",
-       names(formals(f$valid)), "\n","If persist, try different steps or model maybe inappropriate") #
+       names(formals(f$valid)), "\n","Increase gd.tol and if persist, try different steps",  "\n", "or model maybe inappropriate") #
              iterw <-TRUE
               }                      
             if (is.na(!f$valid(fv)) ) # MS Saturday, April 6, 2002 at 18:06 
@@ -235,6 +246,7 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
           d2ldp2 <- f$d2ldp2(fv)
           d2ldp2 <-  ifelse(d2ldp2 < -1e-15, d2ldp2,-1e-15) # added 26-10-07   
               wt <- -(d2ldp2/(dr*dr)) 
+              wt <- ifelse(wt>1e+10,1e+10,wt) # Mikis 9-10-14    
              # wv <- (eta-os)+step*dldp/(dr*wt)
              wv <- (eta-os)+dldp/(dr*wt)
                 if (family$type=="Mixed") wv <-ifelse(is.nan(wv),0,wv) ## TEST  
@@ -246,7 +258,7 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
            } #end of while
            pen <- 0 # DS Thursday, November 21, 2002 at 23:04
            if(length(who) > 0) {pen<- sum(eta*wt*(wv-eta)) }
-           c(fit, list(fv = fv, wv = wv, wt = wt, eta = eta, pen = pen)) #ms Saturday, December 4, 2004 
+           c(fit, list(fv = fv, wv = wv, wt = wt, eta = eta, os = os, pen=pen)) #ms Saturday, December 4, 2004 
          }     
            ##-end of GLIM.fit------------------------------------------------------------
       
@@ -484,21 +496,23 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
                                  who = who.mu, smooth.frame = smooth.frame.mu, maxit = 1, 
                                  tol = bf.tol, trace = bf.trace)
                  mu.fit$eta <<- eta.mu <- mu.fit$fitted.values+mu.offset
-                  mu.fit$fv <<-    mu <<- mu.object$linkinv(eta.mu)
+                  mu.fit$fv <<-  mu <<- mu.object$linkinv(eta.mu)
                     s.mu.old <- s.mu
                         s.mu <- mu.fit$smooth 
                  mu.fit$pen <<- sum(eta.mu*w.mu*(wv.mu-eta.mu))
                   mu.fit$wv <<- wv.mu
                   mu.fit$wt <<- w.mu
+                  mu.fit$os <<- mu.offset
                  
                 }   
                 else 
                 { 
                      mu.fit <<- lm.wfit(x=mu.X,y=wv.mu,w=w.mu*w,method="qr") 
                  mu.fit$eta <<- eta.mu <- mu.fit$fitted.values+mu.offset
-                  mu.fit$fv <<-    mu <<- mu.object$linkinv(eta.mu)
+                  mu.fit$fv <<-   mu <<- mu.object$linkinv(eta.mu)
                   mu.fit$wv <<- wv.mu
-                  mu.fit$wt <<- w.mu   
+                  mu.fit$wt <<- w.mu
+                  mu.fit$os <<- mu.offset      
                 }
              }
             }     
@@ -525,7 +539,8 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
                          s.sigma <- sigma.fit$smooth
                   sigma.fit$pen <<- sum(eta.sigma*w.sigma*(wv.sigma-eta.sigma))
                    sigma.fit$wv <<- wv.sigma
-                   sigma.fit$wt <<- w.sigma 
+                   sigma.fit$wt <<- w.sigma
+                   sigma.fit$os <<- sigma.offset 
                 }   
                 else 
                 { 
@@ -533,7 +548,8 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
               sigma.fit$eta <<- eta.sigma <- sigma.fit$fitted.values+sigma.offset
                sigma.fit$fv <<- sigma    <<- sigma.object$linkinv(eta.sigma) 
                sigma.fit$wv <<- wv.sigma
-               sigma.fit$wt <<- w.sigma   
+               sigma.fit$wt <<- w.sigma 
+               sigma.fit$os <<- sigma.offset   
                 }
              }   
             }
@@ -557,7 +573,8 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
                       s.nu <- nu.fit$smooth 
                nu.fit$pen <<- sum(eta.nu*w.nu*(wv.nu-eta.nu)) 
                 nu.fit$wv <<- wv.nu
-                nu.fit$wt <<- w.nu  
+                nu.fit$wt <<- w.nu 
+                nu.fit$os <<- nu.offset  
                 }   
                 else 
                 { 
@@ -565,7 +582,8 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
               nu.fit$eta <<- eta.nu <- nu.fit$fitted.values+nu.offset
                nu.fit$fv <<-    nu <<- nu.object$linkinv(eta.nu) 
                nu.fit$wv <<- wv.nu
-               nu.fit$wt <<- w.nu       
+               nu.fit$wt <<- w.nu 
+               nu.fit$os <<- nu.offset      
                 } 
               }
              }    
@@ -589,7 +607,8 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
                       s.tau <- tau.fit$smooth 
                tau.fit$pen <<- sum(eta.tau*w.tau*(wv.tau-eta.tau)) 
                 tau.fit$wv <<- wv.tau
-                tau.fit$wt <<- w.tau   
+                tau.fit$wt <<- w.tau 
+                tau.fit$os <<- tau.offset  
                 }   
                 else 
                 { 
@@ -597,7 +616,8 @@ body(rqres) <-  eval(quote(body(rqres)), envir = getNamespace("gamlss"))
                tau.fit$eta <<- eta.tau <- tau.fit$fitted.values+tau.offset
                 tau.fit$fv <<-    tau <<- tau.object$linkinv(eta.tau)
                 tau.fit$wv <<- wv.tau
-                tau.fit$wt <<- w.tau       
+                tau.fit$wt <<- w.tau
+                tau.fit$os <<- tau.offset        
                 }
               }
              }                        
@@ -694,6 +714,7 @@ parameterOut <- function(what="mu", save)
                  out$x <- eval(parse(text=(paste(what,".X", sep=""))))
                 out$qr <- eval(parse(text=(paste(what,".fit$qr", sep="")))) 
       out$coefficients <- eval(parse(text=(paste(what,".fit$coefficients", sep="")))) 
+            out$offset <- eval(parse(text=(paste(what,".fit$os",           sep="")))) 
           out$xlevels  <- .getXlevels( eval(parse(text=paste(what,".terms",sep="")))
                                        , eval(parse(text=paste(what,".frame",sep="")))) 
                                               # ms Sunday, June 13 2004  
@@ -705,13 +726,13 @@ parameterOut <- function(what="mu", save)
                 out$s  <- eval(parse(text=paste(what,".fit$smooth",sep=""))) 
                out$var <- eval(parse(text=paste(what,".fit$var",sep="")))  
            out$coefSmo <- eval(parse(text=paste(what,".fit$coefSmo",sep=""))) 
-            out$lambda <- eval(parse(text=paste(what,".fit$lambda",sep=""))) 
-              out$pen  <- eval(parse(text=paste(what,".fit$pen",sep=""))) 
+            out$lambda <- eval(parse(text=paste(what,".fit$lambda",sep="")))
+               out$pen <- eval(parse(text=paste(what,".fit$pen",sep="")))            
               }
             else                       
               { out$df <- eval(parse(text=paste(what,".fit$rank",sep=""))) 
              out$nl.df <- 0
-              out$pen  <- 0 #ms May 13, 2004 
+             out$pen  <- 0 #ms May 13, 2004 
               }
      }
    else
@@ -728,15 +749,15 @@ parameterOut <- function(what="mu", save)
               { out$df <- eval(parse(text=paste(what,".fit$nl.df",sep="")))+
                           eval(parse(text=paste(what,".fit$rank",sep=""))) 
              out$nl.df <- eval(parse(text=paste(what,".fit$nl.df",sep="")))
-                 out$terms <- eval(parse(text=(paste(what,".terms", sep=""))))
-                  out$formula <- eval(parse(text=paste(what,".formula",sep="")))
+             out$terms <- eval(parse(text=(paste(what,".terms", sep=""))))
+           out$formula <- eval(parse(text=paste(what,".formula",sep="")))
               }
             else                       
               {  
-              out$df <- eval(parse(text=paste(what,".fit$rank",sep=""))) 
-              out$nl.df <- 0
-                 out$terms <- eval(parse(text=(paste(what,".terms", sep=""))))
-                  out$formula <- eval(parse(text=paste(what,".formula",sep="")))
+                out$df <- eval(parse(text=paste(what,".fit$rank",sep=""))) 
+             out$nl.df <- 0
+             out$terms <- eval(parse(text=(paste(what,".terms", sep=""))))
+           out$formula <- eval(parse(text=paste(what,".formula",sep="")))
               }
      }
    else
@@ -785,7 +806,7 @@ smoothers <- a$specials #S convert variable pointers to term pointers
    }
 ##=========================================================================================
 ##-----------------------------------------------------------------------------------------
-## this function creates the parametr objects
+## this function creates the parameter objects
 ##-----------------------------------------------------------------------------------------
 ##=========================================================================================
 get.object <- function(what)
@@ -1111,8 +1132,8 @@ method <- substitute(method)
                            #, na.action=na.act
     out$converged <- conv  
     out$residuals <- eval(family$rqres)
-    noObs <- if(all(trunc(w)==w)) sum(w) else N 
-    out$noObs <- noObs
+            noObs <- if(all(trunc(w)==w)) sum(w) else N 
+        out$noObs <- noObs
 ## binomial denominator 
 if(any(family$family%in%.gamlss.bi.list))  out$bd <- bd        
 ##-----------------------------------------------------------------------------------------
@@ -1128,7 +1149,7 @@ else
  }
 ## define now the degrees of freedom for the fit and residuals
      out$df.fit <- out$mu.df
-        out$pen <- out$mu.pen
+       out$pen <- out$mu.pen
 out$df.residual <- noObs-out$mu.df
 ## Output for dispersion model: ----------------------------------------------------------
 if ("sigma"%in%names(family$parameters))
